@@ -1,12 +1,12 @@
 import os
-rebMs=Exception
-rebMV=False
-rebMp=str
-rebMR=int
-rebMS=range
-rebMy=len
-rebMB=object
-rebMc=True
+qpVoY=Exception
+qpVoF=False
+qpVos=str
+qpVoC=int
+qpVol=range
+qpVoJ=len
+qpVov=object
+qpVoW=True
 import re
 import sys
 import glob
@@ -26,7 +26,7 @@ def read_api_key():
  key=os.environ.get('LOCALSTACK_API_KEY')
  if key:
   return key
- raise rebMs('Unable to retrieve API key. Please configure $LOCALSTACK_API_KEY in your environment')
+ raise qpVoY('Unable to retrieve API key. Please configure $LOCALSTACK_API_KEY in your environment')
 def fetch_key():
  api_key=read_api_key()
  if api_key=='test':
@@ -34,10 +34,10 @@ def fetch_key():
  data={'api_key':api_key,'version':VERSION}
  try:
   logging.getLogger('py.warnings').setLevel(logging.ERROR)
-  result=requests.post('%s/activate'%config.API_URL,json.dumps(data),verify=rebMV)
+  result=requests.post('%s/activate'%config.API_URL,json.dumps(data),verify=qpVoF)
   key_base64=json.loads(result.content)['key']
   cache_key_locally(api_key,key_base64)
- except rebMs:
+ except qpVoY:
   key_base64=load_cached_key(api_key)
  finally:
   logging.getLogger('py.warnings').setLevel(logging.WARNING)
@@ -46,12 +46,12 @@ def fetch_key():
 def cache_key_locally(api_key,key_b64):
  content=get_or_create_file(localstack_config.CONFIG_FILE_PATH)
  configs=json.loads(to_str(content))
- timestamp=rebMp(rebMR(now_utc()))
+ timestamp=qpVos(qpVoC(now_utc()))
  key_raw=to_str(base64.b64decode(key_b64))
- for i in rebMS(rebMy(timestamp)):
+ for i in qpVol(qpVoJ(timestamp)):
   key_raw=str_insert(key_raw,i*2,timestamp[i])
  key_b64=to_str(base64.b64encode(to_bytes(key_raw)))
- configs['cached_key']={'timestamp':rebMR(timestamp),'key_hash':md5(api_key),'key':key_b64}
+ configs['cached_key']={'timestamp':qpVoC(timestamp),'key_hash':md5(api_key),'key':key_b64}
  save_file(localstack_config.CONFIG_FILE_PATH,json.dumps(configs))
  return configs
 def load_cached_key(api_key):
@@ -59,13 +59,13 @@ def load_cached_key(api_key):
  configs=json.loads(to_str(content))
  cached_key=configs['cached_key']
  if cached_key.get('key_hash')!=md5(api_key):
-  raise rebMs('Cached key was created for a different API key')
+  raise qpVoY('Cached key was created for a different API key')
  now=now_utc()
  if(now-cached_key['timestamp'])>MAX_KEY_CACHE_DURATION_SECS:
-  raise rebMs('Cached key expired')
- timestamp=rebMp(cached_key['timestamp'])
+  raise qpVoY('Cached key expired')
+ timestamp=qpVos(cached_key['timestamp'])
  key_raw=to_str(base64.b64decode(cached_key['key']))
- for i in rebMS(rebMy(timestamp)):
+ for i in qpVol(qpVoJ(timestamp)):
   assert key_raw[i]==timestamp[i]
   key_raw=str_remove(key_raw,i)
  key_b64=to_str(base64.b64encode(to_bytes(key_raw)))
@@ -104,11 +104,11 @@ def cleanup_environment():
       if os.path.exists(delete_file):
        os.remove(delete_file)
 def prepare_environment():
- class OnClose(rebMB):
+ class OnClose(qpVov):
   def __exit__(self,*args,**kwargs):
    if not ENV_PREPARED.get('finalized'):
     cleanup_environment()
-   ENV_PREPARED['finalized']=rebMc
+   ENV_PREPARED['finalized']=qpVoW
   def __enter__(self,*args,**kwargs):
    pass
  if not ENV_PREPARED.get('finalized'):
@@ -117,7 +117,7 @@ def prepare_environment():
    if key!='test':
     decrypt_files(key)
     LOG.info('Successfully activated API key')
-  except rebMs:
+  except qpVoY:
    if config.REQUIRE_PRO:
     LOG.error('Unable to activate API key, but $REQUIRE_PRO is configured - quitting.')
     sys.exit(1)
