@@ -1,11 +1,11 @@
 import os
-YNrFk=Exception
-YNrFb=any
-YNrFz=str
-YNrFO=None
-YNrFK=False
-YNrFl=bool
-YNrFP=True
+BefDc=Exception
+BefDH=any
+BefDu=str
+BefDJ=None
+BefDY=False
+BefDI=bool
+BefDm=True
 import logging
 from localstack import config as localstack_config
 from localstack.utils import common
@@ -14,7 +14,7 @@ from localstack.utils.bootstrap import is_api_enabled,API_DEPENDENCIES
 from localstack_ext import config as config_ext
 from localstack_ext.bootstrap import licensing,cli,install,local_daemon
 LOG=logging.getLogger(__name__)
-EXTERNAL_PORT_APIS=('apigateway','athena','cloudfront','codecommit','ecs','ecr','elasticache','mediastore','rds','transfer','kafka','neptune')
+EXTERNAL_PORT_APIS=('apigateway','athena','cloudfront','codecommit','ecs','ecr','elasticache','mediastore','rds','transfer','kafka','neptune','azure')
 def register_localstack_plugins():
  _setup_logging()
  is_infra_process=os.environ.get(LOCALSTACK_INFRA_PROCESS)in TRUE_STRINGS
@@ -29,14 +29,14 @@ def register_localstack_plugins():
   try:
    from localstack_ext.services import dns_server
    dns_server.setup_network_configuration()
-  except YNrFk:
+  except BefDc:
    return
   if is_infra_process:
    load_plugin_files()
   try:
    if is_api_key_configured and not is_infra_process and is_api_enabled('ec2'):
     local_daemon.start_in_background()
-  except YNrFk as e:
+  except BefDc as e:
    LOG.warning('Unable to start local daemon process: %s'%e)
   if is_api_key_configured:
    port=localstack_config.EDGE_PORT
@@ -64,12 +64,14 @@ def register_localstack_plugins():
    docker_flags+=['-p {a}:{p}:{p}'.format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
   if not common.is_port_open(dns_server.DNS_PORT,protocols='udp'):
    docker_flags+=['-p {a}:{p}:{p}/udp'.format(a=config_ext.DNS_ADDRESS,p=dns_server.DNS_PORT)]
- if YNrFb([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
+ if BefDH([is_api_enabled(api)for api in EXTERNAL_PORT_APIS]):
   docker_flags+=['-p {start}-{end}:{start}-{end}'.format(start=config_ext.SERVICE_INSTANCES_PORTS_START,end=config_ext.SERVICE_INSTANCES_PORTS_END)]
  if is_api_enabled('eks'):
   kube_config=os.path.expanduser('~/.kube/config')
   if os.path.exists(kube_config):
    docker_flags+=['-v %s:/root/.kube/config'%kube_config]
+ if is_api_enabled('azure'):
+  docker_flags+=['-p {port}:{port}'.format(port=5671)]
  if os.environ.get('AZURE'):
   docker_flags+=['-p {p}:{p}'.format(p=config_ext.PORT_AZURE)]
  result={'docker':{'run_flags':' '.join(docker_flags)}}
@@ -178,24 +180,24 @@ def load_plugin_files():
   aws_utils.patch_aws_stack()
   edge.patch_start_edge()
   patch_start_infra()
- except YNrFk as e:
-  if 'No module named' not in YNrFz(e):
+ except BefDc as e:
+  if 'No module named' not in BefDu(e):
    print(e)
 def patch_start_infra():
  from localstack.services import infra
  try:
   from localstack_ext.utils.aws.metadata_service import start_metadata_service
- except YNrFk:
-  start_metadata_service=YNrFO
+ except BefDc:
+  start_metadata_service=BefDJ
  def do_start_infra(asynchronous,apis,is_in_docker,*args,**kwargs):
   if common.in_docker():
    try:
     start_metadata_service and start_metadata_service()
-   except YNrFk:
+   except BefDc:
     pass
   enforce_before=config_ext.ENFORCE_IAM
   try:
-   config_ext.ENFORCE_IAM=YNrFK
+   config_ext.ENFORCE_IAM=BefDY
    return do_start_infra_orig(asynchronous,apis,is_in_docker,*args,**kwargs)
   finally:
    config_ext.ENFORCE_IAM=enforce_before
@@ -218,9 +220,9 @@ def _setup_logging():
  logging.getLogger('root').setLevel(logging.WARNING)
  logging.getLogger('').setLevel(logging.WARNING)
 def api_key_configured():
- return YNrFl(os.environ.get('LOCALSTACK_API_KEY'))
+ return BefDI(os.environ.get('LOCALSTACK_API_KEY'))
 def register_localstack_commands():
  if api_key_configured():
   cli.register_commands()
- return YNrFP
+ return BefDm
 # Created by pyminifier (https://github.com/liftoff/pyminifier)
